#ifndef _XfwfCircularPercentage_h
#define _XfwfCircularPercentage_h

#ifndef XtNborderColor
#define XtNborderColor "borderColor"
#endif

#ifndef XtCBorderColor
#define XtCBorderColor "BorderColor"
#endif

#define XtNinteriorColor "interiorColor"
#define XtCInteriorColor "InteriorColor"

#define XtNcompletedColor "completedColor"
#define XtCCompletedColor "CompletedColor"

#define XtNpercentageCompleted "percentageCompleted"
#define XtCPercentageCompleted "PercentageCompleted"

#if defined(__cplusplus) || defined(c_plusplus)
extern "C" {
#endif

	extern WidgetClass xfwfCircularPercentageWidgetClass;

	typedef struct _XfwfCircularPercentageClassRec
	    *XfwfCircularPercentageWidgetClass;
	typedef struct _XfwfCircularPercentageRec
	    *XfwfCircularPercentageWidget;

	extern void XfwfCircularPercentageSetPercentage(Widget, int);

#if defined(__cplusplus) || defined(c_plusplus)
}				/* Close scope of 'extern "C"' declaration which encloses file. */
#endif
#endif
